Author: Wouter van Wijk
Description: MusicBox

- Home
- Now Playing
- Queue
- Playlists
- Browse
- Streams
- Search
- Fullscreen
- Exit Fullscreen
- Settings
- System
- Volume

Close

###

####

Close

####

- Play
- Play Track Next
- Add Track to Bottom of Queue
- Add all to Bottom of Queue
- Show Album
- Show Artist

## Artists

- Play
- Remove from Queue
- Show Album
- Show Artist

## Artists

# Musicbox

#### Now Playing

#### Queue

#### Playlists

#### Browse

#### Streams

#### Search

#### Settings

#### System

###

-

0:00 0:00 Position

Back

### Browse

####

Clear

#### Play Queue

###

#####

###

#### Artists

#### Albums

#### Tracks

#### Streams

Add an url of a stream that you want to listen to in the box below. You can add uri's for Spotify, SoundCloud, YouTube, Podcasts.

Put in a name and hit the Save button to save the url (locally, in the browser not on the server yet).